@@ -180,8 +180,6 @@ def model(ctx,
         
         for ckpt_path in ckpt_items:
             eval_ckpt_paths_list.append(os.path.join(ckpt_paths, ckpt_path))
-        
-        print(f"✅ Found {len(eval_ckpt_paths_list)} checkpoint(s) in directory: {ckpt_paths}")
     else:  # ckpt_list is provided
         ckpt_list_paths = [path.strip() for path in ckpt_list.split(',')]
         
@@ -225,6 +223,23 @@ def model(ctx,
             print("❌ No valid checkpoint paths found. Cannot proceed.")
             sys.exit(1)
     
+    # Sort by the numeric value that follows 'step=' in the filename
+    def _extract_step_from_path(path: str) -> int:
+        try:
+            if 'step=' in path:
+                tail = path.split('step=')[1]
+                digits = []
+                for ch in tail:
+                    if ch.isdigit():
+                        digits.append(ch)
+                    else:
+                        break
+                return int(''.join(digits)) if digits else 0
+        except Exception:
+            pass
+        return 0
+    # Ensure a consistent order in list mode as well: sort by 'step='
+    eval_ckpt_paths_list.sort(key=_extract_step_from_path)
     # Process dataset paths
     final_dataset_paths = None
     if dataset_paths:
